@@ -32,7 +32,7 @@ def _enum_coerce(self, enum, value):
 	if value is None:
 		return None
 	
-	elif value in enum:
+	elif isinstance(value, EnumItem) and value in enum:
 		return value
 	
 	try:
@@ -40,7 +40,6 @@ def _enum_coerce(self, enum, value):
 	except ValueError:
 		raise exceptions.ValidationError(self.error_messages['invalid'] % value)
 
-
 class EnumFormField(forms.TypedChoiceField):
 	
 	def __init__(self, enum, *args, **kwargs):
